.. :changelog:

History
-------

0.0.1 (2016-12-16)
------------------

* First packaged release


2.0.7 (2017-02-14)
------------------

* Reverting to modify locale to change datetime
* Using dateparser module
